@@ -1,7 +1,9 @@
 import os
 import sys
 from insights.client.constants import InsightsConstants as constants
-from insights.client.apps.ansible.playbook_verifier import verify, loadPlaybookYaml
+from insights.client.apps.ansible.playbook_verifier import verify, loadPlaybookYaml, PlaybookVerificationError
+
+skipVerify = False
 
 
 def read_playbook():
@@ -15,17 +17,15 @@ def read_playbook():
     return unverified_playbook
 
 
-playbook = read_playbook()
-playbook_yaml = loadPlaybookYaml(playbook)
-skipVerify = False
-
 if (os.environ.get('SKIP_VERIFY')):
     skipVerify = True
 
 try:
+    playbook = read_playbook()
+    playbook_yaml = loadPlaybookYaml(playbook)
     verified_playbook = verify(playbook_yaml, skipVerify)
-except Exception as e:
-    sys.stderr.write(e.message)
+except PlaybookVerificationError as err:
+    sys.stderr.write(err.message)
     sys.exit(constants.sig_kill_bad)
 
 print(playbook)
