@@ -601,9 +601,7 @@ class MalwareDetectionClient:
             logger.debug("Removing old rules file %s", old_rules_file)
             os.remove(old_rules_file)
 
-        self.rules_location = self._get_config_option(
-            'rules_location', "https://console.redhat.com/api/malware-detection/v1/signatures.yar"
-        )
+        self.rules_location = self._get_config_option('rules_location', '')
 
         # If rules_location starts with a /, assume its a file rather than a URL
         if self.rules_location.startswith('/'):
@@ -621,19 +619,26 @@ class MalwareDetectionClient:
             logger.error("Couldn't access the insights-client configuration")
             exit(constants.sig_kill_bad)
 
+        if not self.rules_location:
+            self.rules_location = "https://console.redhat.com/api/malware-detection/v1/signatures.yar"
+            if '/redhat_access/' in self.insights_config.base_url:
+                # Satellite URLs have '/redhat_access/' in the base_url config option
+                self.rules_location = self.insights_config.base_url + '/malware-detection/v1/signatures.yar'
+
         # Make sure the rules_location starts with https://
         if not re.match('^https?://', self.rules_location):
             self.rules_location = 'https://' + self.rules_location
 
-        # if insights-client is using cert auth or basic auth without a username and password, append 'cert.' to the url
-        authmethod = self.insights_config.authmethod if hasattr(self.insights_config, 'authmethod') else 'CERT'
-        username = self.insights_config.username if hasattr(self.insights_config, 'username') else ''
-        password = self.insights_config.password if hasattr(self.insights_config, 'password') else ''
-        if authmethod == 'CERT' or (authmethod == 'BASIC' and not (username or password)):
-            self.insights_config.authmethod = 'CERT'
-            parsed_url = urlparse(self.rules_location)
-            if not parsed_url.netloc.startswith('cert.'):
-                self.rules_location = urlunparse(parsed_url._replace(netloc='cert.' + parsed_url.netloc))
+        # If talking direct to C.R.C with cert auth or basic auth without a username/password, append 'cert.' to the url
+        if self.rules_location.startswith('https://console.redhat.com'):
+            authmethod = self.insights_config.authmethod if hasattr(self.insights_config, 'authmethod') else 'CERT'
+            username = self.insights_config.username if hasattr(self.insights_config, 'username') else ''
+            password = self.insights_config.password if hasattr(self.insights_config, 'password') else ''
+            if authmethod == 'CERT' or (authmethod == 'BASIC' and not (username or password)):
+                self.insights_config.authmethod = 'CERT'
+                parsed_url = urlparse(self.rules_location)
+                if not parsed_url.netloc.startswith('cert.'):
+                    self.rules_location = urlunparse(parsed_url._replace(netloc='cert.' + parsed_url.netloc))
 
         # If doing a test scan, replace signatures.yar (or any other file suffix) with test-rule.yar
         log_rule_contents = False
