@@ -161,6 +161,17 @@ plugins:
         - name: insights.combiners.httpd_conf._HttpdConf
           enabled: true
 
+    # needed for nginx_ssl_cert_enddate
+        - name: insights.combiners.nginx_conf.NginxConfTree
+          enabled: true
+
+        - name: insights.combiners.nginx_conf._NginxConf
+          enabled: true
+
+    # needed for mssql_tls_cert_enddate
+        - name: insights.parsers.mssql_conf.MsSQLConf
+          enabled: true
+
     # needed to collect the sap_hdb_version spec that uses the Sap combiner
         - name: insights.parsers.lssap
           enabled: true
@@ -207,6 +218,12 @@ plugins:
           enabled: true
         - name: insights.components.rhel_version.IsRhel8
           enabled: true
+        - name: insights.components.rhel_version.IsRhel9
+          enabled: true
+
+    # needed for the 'pmlog_summary' spec
+        - name: insights.parsers.ros_config.RosConfig
+          enabled: true
 
     # needed because some specs aren't given names before they're used in DefaultSpecs
         - name: insights.core.spec_factory
