@@ -75,7 +75,10 @@ class AwxManagePrintSettings(CommandParser, JSONParser):
             "INSIGHTS_TRACKING_STATE": true,
             "INSTALL_UUID": "c0d38a6a-4449-4e13-a64b-00e0248ad229",
             "SYSTEM_UUID": "eecfd8dc-5028-46ef-9868-86f7d595da13",
-            "TOWER_URL_BASE": "https://10.72.37.79"
+            "TOWER_URL_BASE": "https://10.72.37.79",
+            "LOG_AGGREGATOR_ENABLED": true,
+            "LOG_AGGREGATOR_LEVEL": "DEBUG"
+
         }
 
     Examples:
@@ -85,5 +88,9 @@ class AwxManagePrintSettings(CommandParser, JSONParser):
         False
         >>> settings['SYSTEM_UUID'] == 'eecfd8dc-5028-46ef-9868-86f7d595da13'
         True
+        >>> settings['LOG_AGGREGATOR_ENABLED']
+        True
+        >>> settings['LOG_AGGREGATOR_LEVEL'] == 'DEBUG'
+        True
     """
     pass
