@@ -1,4 +1,6 @@
-from insights.parsers.neutron_conf import NeutronConf
+import doctest
+
+from insights.parsers import neutron_conf
 from insights.tests import context_wrap
 
 NEUTRON_CONF = """
@@ -16,17 +18,25 @@ quota_network = 10
 report_interval = 60
 
 [keystone_authtoken]
-auth_host = ost-controller-lb-del.om-l.dsn.inet
+auth_host = ost-controller-lb-del.example.com
 auth_port = 35357
 [database]
-connection = mysql://neutron:dSNneutron01@ost-mysql.om-l.dsn.inet/neutron?ssl_ca=/etc/pki/CA/certs/ca.crt
+connection = mysql://neutron:dSNneutron01@ost-mysql.example.com/neutron?ssl_ca=/etc/pki/CA/certs/ca.crt
 [service_providers]
 service_provider = LOADBALANCER:Haproxy:neutron.services.loadbalancer.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default
 """
 
 
+def test_doc_examples():
+    failed_count, tests = doctest.testmod(
+        neutron_conf,
+        globs={'conf': neutron_conf.NeutronConf(context_wrap(NEUTRON_CONF))}
+    )
+    assert failed_count == 0
+
+
 def test_neutron_conf():
-    nconf = NeutronConf(context_wrap(NEUTRON_CONF))
+    nconf = neutron_conf.NeutronConf(context_wrap(NEUTRON_CONF))
     assert nconf is not None
     assert list(nconf.sections()) == ['quotas', 'agent', 'keystone_authtoken', 'database', 'service_providers']
     assert nconf.defaults() == {
