@@ -90,6 +90,7 @@ class Specs(SpecSet):
     cpuinfo = RegistryPoint()
     cpupower_frequency_info = RegistryPoint()
     cpuset_cpus = RegistryPoint()
+    crictl_logs = RegistryPoint(multi_output=True, filterable=True)
     crio_conf = RegistryPoint(multi_output=True)
     cron_daily_rhsmd = RegistryPoint(filterable=True)
     crypto_policies_config = RegistryPoint()
@@ -102,6 +103,7 @@ class Specs(SpecSet):
     date_iso = RegistryPoint()
     date = RegistryPoint()
     date_utc = RegistryPoint()
+    db2ls_a_c = RegistryPoint()
     designate_conf = RegistryPoint(filterable=True)
     dcbtool_gc_dcb = RegistryPoint(multi_output=True)
     df__alP = RegistryPoint()
@@ -240,6 +242,8 @@ class Specs(SpecSet):
     httpd_ssl_error_log = RegistryPoint(filterable=True)
     httpd_V = RegistryPoint(multi_output=True)
     virt_uuid_facts = RegistryPoint()
+    ibm_fw_vernum_encoded = RegistryPoint()
+    ibm_lparcfg = RegistryPoint(filterable=True)
     ifcfg = RegistryPoint(multi_output=True)
     ifcfg_static_route = RegistryPoint(multi_output=True)
     ifconfig = RegistryPoint()
@@ -291,6 +295,7 @@ class Specs(SpecSet):
     kpatch_list = RegistryPoint()
     krb5 = RegistryPoint(multi_output=True)
     ksmstate = RegistryPoint()
+    ktimer_lockless = RegistryPoint()
     kubepods_cpu_quota = RegistryPoint(multi_output=True)
     lastupload = RegistryPoint(multi_output=True)
     ld_library_path_of_user = RegistryPoint()
@@ -313,6 +318,7 @@ class Specs(SpecSet):
     ls_docker_volumes = RegistryPoint()
     ls_edac_mc = RegistryPoint()
     ls_etc = RegistryPoint()
+    ls_etc_systemd = RegistryPoint()
     ls_ipa_idoverride_memberof = RegistryPoint()
     ls_lib_firmware = RegistryPoint()
     ls_ocp_cni_openshift_sdn = RegistryPoint()
@@ -323,6 +329,7 @@ class Specs(SpecSet):
     ls_sys_firmware = RegistryPoint()
     ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
+    ls_usr_lib_systemd = RegistryPoint()
     ls_usr_sbin = RegistryPoint(filterable=True)
     ls_var_cache_pulp = RegistryPoint()
     ls_var_lib_mongodb = RegistryPoint()
@@ -458,6 +465,7 @@ class Specs(SpecSet):
     oc_get_service = RegistryPoint()
     oc_get_configmap = RegistryPoint()
     octavia_conf = RegistryPoint(filterable=True)
+    od_cpu_dma_latency = RegistryPoint()
     odbc_ini = RegistryPoint(filterable=True)
     odbcinst_ini = RegistryPoint()
     open_vm_tools_stat_raw_text_session = RegistryPoint()
@@ -593,8 +601,11 @@ class Specs(SpecSet):
     satellite_custom_ca_chain = RegistryPoint()
     satellite_custom_hiera = RegistryPoint()
     satellite_katello_empty_url_repositories = RegistryPoint()
+    satellite_katello_repos_with_muliple_ref = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
     satellite_non_yum_type_repos = RegistryPoint()
+    satellite_qualified_capsules = RegistryPoint()
+    satellite_qualified_katello_repos = RegistryPoint()
     satellite_sca_status = RegistryPoint()
     satellite_settings = RegistryPoint()
     satellite_version_rb = RegistryPoint()
@@ -657,9 +668,11 @@ class Specs(SpecSet):
     sysconfig_prelink = RegistryPoint()
     sysconfig_sshd = RegistryPoint()
     sysconfig_virt_who = RegistryPoint()
-    sysctl_conf_initramfs = RegistryPoint(multi_output=True)
-    sysctl_conf = RegistryPoint()
     sysctl = RegistryPoint()
+    sysctl_conf = RegistryPoint()
+    sysctl_conf_initramfs = RegistryPoint(multi_output=True)
+    sysctl_d_conf_etc = RegistryPoint(multi_output=True)
+    sysctl_d_conf_usr = RegistryPoint(multi_output=True)
     systemctl_cat_dnsmasq_service = RegistryPoint()
     systemctl_cat_rpcbind_socket = RegistryPoint()
     systemctl_cinder_volume = RegistryPoint()
